# -*- coding: utf-8 -*-
from __future__ import unicode_literals, absolute_import
from django.apps import AppConfig


class AldrynApphookReloadConfig(AppConfig):
    name = 'aldryn_apphook_reload'
    verbose_name = "Aldryn Apphook Reload"
